==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/ListActiveSecurityAdminRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the request to list active security admin rules. It contains a list of active security admin rules and a skiptoken to get the next set of results.
 * @property skipToken When present, the value can be passed to a subsequent query call (together with the same query and scopes used in the current request) to retrieve the next page of data.
 * @property value Gets a page of active security admin rules.
 */
public data class ListActiveSecurityAdminRuleResult(
    public val skipToken: String? = null,
    public val `value`:
    List<Either<ActiveDefaultSecurityAdminRuleResponse, ActiveSecurityAdminRuleResponse>>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.ListActiveSecurityAdminRuleResult):
            ListActiveSecurityAdminRuleResult = ListActiveSecurityAdminRuleResult(
            skipToken = javaType.skipToken().map({ args0 -> args0 }).orElse(null),
            `value` = javaType.`value`().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.network.kotlin.outputs.ActiveDefaultSecurityAdminRuleResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.network.kotlin.outputs.ActiveSecurityAdminRuleResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/ListActiveSecurityAdminRuleResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import com.pulumi.core.Either
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Result of the request to list active security admin rules. It contains a list of active security admin rules and a skiptoken to get the next set of results.
 * @property skipToken When present, the value can be passed to a subsequent query call (together with the same query and scopes used in the current request) to retrieve the next page of data.
 * @property value Gets a page of active security admin rules.
 */
public data class ListActiveSecurityAdminRuleResult(
    public val skipToken: String? = null,
    public val `value`: List<Either<ActiveDefaultSecurityAdminRuleResponse, ActiveSecurityAdminRuleResponse>>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.ListActiveSecurityAdminRuleResult): ListActiveSecurityAdminRuleResult = ListActiveSecurityAdminRuleResult(
            skipToken = javaType.skipToken().map({ args0 -> args0 }).orElse(null),
            `value` = javaType.`value`().map({ args0 ->
                args0.transform(
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.network.kotlin.outputs.ActiveDefaultSecurityAdminRuleResponse.Companion.toKotlin(args0)
                        })
                    },
                    { args0 ->
                        args0.let({ args0 ->
                            com.pulumi.azurenative.network.kotlin.outputs.ActiveSecurityAdminRuleResponse.Companion.toKotlin(args0)
                        })
                    },
                )
            }),
        )
    }
}
